Module divergence

Module divergence 

Protocol Divergence Localization

Identifies WHERE in a network path different protocols start behaving differently. Runs ICMP, TCP, and UDP traceroutes in parallel and compares results at each hop.

Structs

DivergenceHop
Combined results for all protocols at a single hop
DivergenceOptions
Options for divergence analysis
DivergenceResult
Complete divergence analysis result
ProtocolHopResult
Result for a single protocol at a single hop

Enums

DivergenceProtocol
Protocol used for probing
HopStatus
Status of a protocol probe at a specific hop

Functions

analyze_divergence
Run divergence analysis - trace route with multiple protocols and compare