Probe

Struct Probe 

pub struct Probe;
Entry point for creating probes

Use the static methods to create different probe types:

  • Probe::icmp() for ICMP ping
  • Probe::tcp() for TCP connect probe
  • Probe::udp() for UDP probe
  • Probe::multi() for multi-protocol probing

Implementations

Source

impl Probe

pub fn icmp(target: &str) -> IcmpProbe

Create a new ICMP ping probe

pub fn tcp(target: &str, port: u16) -> TcpProbe

Create a new TCP connect probe

pub fn udp(target: &str, port: u16) -> UdpProbe

Create a new UDP probe

pub fn multi(target: &str) -> MultiProbe

Create a multi-protocol probe builder

pub fn traceroute(target: &str) -> TracerouteBuilder

Create a traceroute builder

pub fn paris(target: &str) -> ParisBuilder

Create a Paris Traceroute builder (ECMP-aware)

pub fn tls(target: &str) -> TlsBuilder

Create a TLS probe builder

pub fn latency(target: &str, port: u16) -> LatencyBuilder

Create a latency measurement builder

pub fn mtu(target: &str) -> MtuBuilder

Create a Path MTU Discovery builder

pub fn bufferbloat(target: &str) -> BufferbloatBuilder

Create a bufferbloat detection builder

pub fn bidirectional(target: &str) -> BidirectionalBuilder

Create a bidirectional probe builder for detecting path asymmetry

Requires a multiprobe server running on the target. Start a server with: BidirectionalServer::bind("0.0.0.0:33435").await?.run().await