pub struct Probe;Expand description
Entry point for creating probes
Use the static methods to create different probe types:
Probe::icmp()for ICMP pingProbe::tcp()for TCP connect probeProbe::udp()for UDP probeProbe::multi()for multi-protocol probing
Implementations
Sourceimpl Probe
impl Probe
Sourcepub fn traceroute(target: &str) -> TracerouteBuilder
pub fn traceroute(target: &str) -> TracerouteBuilder
Create a traceroute builder
Sourcepub fn bufferbloat(target: &str) -> BufferbloatBuilder
pub fn bufferbloat(target: &str) -> BufferbloatBuilder
Create a bufferbloat detection builder
Sourcepub fn bidirectional(target: &str) -> BidirectionalBuilder
pub fn bidirectional(target: &str) -> BidirectionalBuilder
Create a bidirectional probe builder for detecting path asymmetry
Requires a multiprobe server running on the target.
Start a server with: BidirectionalServer::bind("0.0.0.0:33435").await?.run().await